# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: versions_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import versions_common_pb2 as versions__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16versions_service.proto\x12\x1c\x61rmonik.api.grpc.v1.versions\x1a\x15versions_common.proto2\x83\x01\n\x08Versions\x12w\n\x0cListVersions\x12\x31.armonik.api.grpc.v1.versions.ListVersionsRequest\x1a\x32.armonik.api.grpc.v1.versions.ListVersionsResponse\"\x00\x42\x1f\xaa\x02\x1c\x41rmonik.Api.Grpc.V1.Versionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'versions_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\034Armonik.Api.Grpc.V1.Versions'
  _globals['_VERSIONS']._serialized_start=80
  _globals['_VERSIONS']._serialized_end=211
# @@protoc_insertion_point(module_scope)
