# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: partitions_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import sort_direction_pb2 as sort__direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17partitions_common.proto\x12\x1e\x61rmonik.api.grpc.v1.partitions\x1a\x14sort_direction.proto\"\xa8\x02\n\x0cPartitionRaw\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1c\n\x14parent_partition_ids\x18\x02 \x03(\t\x12\x14\n\x0cpod_reserved\x18\x03 \x01(\x03\x12\x0f\n\x07pod_max\x18\x04 \x01(\x03\x12]\n\x11pod_configuration\x18\x07 \x03(\x0b\x32\x42.armonik.api.grpc.v1.partitions.PartitionRaw.PodConfigurationEntry\x12\x1d\n\x15preemption_percentage\x18\x05 \x01(\x03\x12\x10\n\x08priority\x18\x06 \x01(\x03\x1a\x37\n\x15PodConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x0ePartitionField\x12P\n\x13partition_raw_field\x18\x01 \x01(\x0e\x32\x31.armonik.api.grpc.v1.partitions.PartitionRawFieldH\x00\x42\x07\n\x05\x66ield\"\xea\x03\n\x15ListPartitionsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12L\n\x06\x66ilter\x18\x03 \x01(\x0b\x32<.armonik.api.grpc.v1.partitions.ListPartitionsRequest.Filter\x12H\n\x04sort\x18\x04 \x01(\x0b\x32:.armonik.api.grpc.v1.partitions.ListPartitionsRequest.Sort\x1a\x89\x01\n\x06\x46ilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1b\n\x13parent_partition_id\x18\x02 \x01(\t\x12\x14\n\x0cpod_reserved\x18\x03 \x01(\x05\x12\x0f\n\x07pod_max\x18\x04 \x01(\x05\x12\x1d\n\x15preemption_percentage\x18\x05 \x01(\x05\x12\x10\n\x08priority\x18\x06 \x01(\x05\x1a\x8b\x01\n\x04Sort\x12=\n\x05\x66ield\x18\x01 \x01(\x0b\x32..armonik.api.grpc.v1.partitions.PartitionField\x12\x44\n\tdirection\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sort_direction.SortDirection\"\x8a\x01\n\x16ListPartitionsResponse\x12@\n\npartitions\x18\x01 \x03(\x0b\x32,.armonik.api.grpc.v1.partitions.PartitionRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"!\n\x13GetPartitionRequest\x12\n\n\x02id\x18\x01 \x01(\t\"W\n\x14GetPartitionResponse\x12?\n\tpartition\x18\x01 \x01(\x0b\x32,.armonik.api.grpc.v1.partitions.PartitionRaw*\x9a\x02\n\x11PartitionRawField\x12#\n\x1fPARTITION_RAW_FIELD_UNSPECIFIED\x10\x00\x12\x1a\n\x16PARTITION_RAW_FIELD_ID\x10\x01\x12,\n(PARTITION_RAW_FIELD_PARENT_PARTITION_IDS\x10\x02\x12$\n PARTITION_RAW_FIELD_POD_RESERVED\x10\x03\x12\x1f\n\x1bPARTITION_RAW_FIELD_POD_MAX\x10\x04\x12-\n)PARTITION_RAW_FIELD_PREEMPTION_PERCENTAGE\x10\x05\x12 \n\x1cPARTITION_RAW_FIELD_PRIORITY\x10\x06\x42!\xaa\x02\x1e\x41rmonik.Api.Grpc.V1.Partitionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'partitions_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\036Armonik.Api.Grpc.V1.Partitions'
  _PARTITIONRAW_PODCONFIGURATIONENTRY._options = None
  _PARTITIONRAW_PODCONFIGURATIONENTRY._serialized_options = b'8\001'
  _globals['_PARTITIONRAWFIELD']._serialized_start=1248
  _globals['_PARTITIONRAWFIELD']._serialized_end=1530
  _globals['_PARTITIONRAW']._serialized_start=82
  _globals['_PARTITIONRAW']._serialized_end=378
  _globals['_PARTITIONRAW_PODCONFIGURATIONENTRY']._serialized_start=323
  _globals['_PARTITIONRAW_PODCONFIGURATIONENTRY']._serialized_end=378
  _globals['_PARTITIONFIELD']._serialized_start=380
  _globals['_PARTITIONFIELD']._serialized_end=487
  _globals['_LISTPARTITIONSREQUEST']._serialized_start=490
  _globals['_LISTPARTITIONSREQUEST']._serialized_end=980
  _globals['_LISTPARTITIONSREQUEST_FILTER']._serialized_start=701
  _globals['_LISTPARTITIONSREQUEST_FILTER']._serialized_end=838
  _globals['_LISTPARTITIONSREQUEST_SORT']._serialized_start=841
  _globals['_LISTPARTITIONSREQUEST_SORT']._serialized_end=980
  _globals['_LISTPARTITIONSRESPONSE']._serialized_start=983
  _globals['_LISTPARTITIONSRESPONSE']._serialized_end=1121
  _globals['_GETPARTITIONREQUEST']._serialized_start=1123
  _globals['_GETPARTITIONREQUEST']._serialized_end=1156
  _globals['_GETPARTITIONRESPONSE']._serialized_start=1158
  _globals['_GETPARTITIONRESPONSE']._serialized_end=1245
# @@protoc_insertion_point(module_scope)
